// Schlumberger Industries, SA, 1996. All rights reserved.

#ifndef SLBAPI_INC
#define SLBAPI_INC

#include <windows.h>

/*
#ifndef _SCR60API
	#ifdef __BORLANDC__
*/

#define _SCR60API
/*
#define _SCR60API _EXPORT */

/*
	#else
		#define	_SCR60API __declspec(dllexport)
	#endif
#endif
*/



////////////////////////////////////////////////////////////////////////////////
//
// Reader States

// This value implies that a system error has occurred.
#define SLBAPI_SYSTEMERROR    		0x00

// This value implies that the reader is not available for use, either because it is in
// use by another application, or because it is off line.
#define SLBAPI_UNAVAILABLE     		0x01

// This value implies that there is no card in the reader.
// This is the base state; the reader goes to this state on successful allocation,
// and whenever a card is removed.
// The reader goes to the next state when a card is inserted.
#define SLBAPI_CARDABSENT          	0x02

// This value implies that there is a card is in position for use.
// The reader goes on to the next state following successful execution of
// the SLBAPIPowerUp command.
#define SLBAPI_CARDSWALLOWED       	0x03

// This value implies there is power is being provided to the card.
// The reader goes on to either of the next two states following
// successful execution of the SLBAPIReset command,
// depending on the received ATR string.
#define SLBAPI_CARDPOWERED         	0x04

// This value implies that the card has been reset, but the reader is not capable of dealing with
// a card of this type.
#define SLBAPI_CARDUNKNOWN		     	0x05

// This value implies the card has been reset and is awaiting PTS negotiation.
// The reader goes on to the next state following successful PTS negotiation.
#define SLBAPI_NEGOTIABLEMODE  		0x06

// This value implies the card has been reset and specific communication protocols have
// been established.
#define SLBAPI_SPECIFICMODE    		0x07


// This value implies that there was a problem with the T=1 protocol. The card has to be reset.
#define SLBAPI_PROTOCOLERROR			0x10

//==============================================================================

//	Error codes

// This value implies that the card did not answer before the timeout.
#define SLBAPI_TIMEOUT					0x08

// This value implies that the command has been aborted
#define SLBAPI_ABORTED					0x09

// This value implies that an error occured during the execution of the command
#define SLBAPI_ERROR						0x0A

// This value implies that all went well
#define SLBAPI_OK							0x0B

//------------------------------------------------------------------------------

 // No protocol has been established
#define SLBAPI_PROTOCOLUNDEFINED  	0xFF

 // The ISO 7816/3 T=0 Protocol is in use.
#define SLBAPI_PROTOCOLT0           0xF0

// The ISO 7816/3 T=1 Protocol is in use.
// 2 - 15 Reserved for new ISO protocols.
#define SLBAPI_PROTOCOLT1           0xF1

// The Raw Transfer Protocol is in use.
#define SLBAPI_PROTOCOLRAW          0xFE

// The ISO 7816/3 PTS Protocol is in use.
#define SLBAPI_PROTOCOLPTS          0xF2

// The Synchronous Protocol is in use.
#define SLBAPI_CARDSYNCHRONOUS  		0xF3

//==============================================================================

// reader types

// a serial reader
#define SLBAPI_RT_SERIAL	0x00

// a PCMCIA reader ( = Reflex 20 )
#define SLBAPI_RT_PCMCIA	0x01

//==============================================================================

// These constants are used to call UCRS extended functions.
// They are used in the call of SLBAPICallExtendedFunction
#define UCRS_FCT_GETSPEED				200
#define UCRS_FCT_CHANGECLOCK			201
#define UCRS_FCT_TESTANTITEARING		202

//#ifdef __ALTERATEDT1__ 
// These constants are used to call SCR and Rfl60 extended functions.
// They are used in the call of SLBAPICallExtendedFunction
#define FCT_SENDALTERATEDT1				300
#define FCT_GETPARAMETERST1				301
//#endif

// Structure APIEXTENDEDPARAM used to pass and gets arguments for SLBAPICallExtendedFunction
typedef struct
{             		// 	IN													OUT
	BOOL bParam; 	// not used                       			not used
	int iParam1; 	// nb of digits of the PIN in SPE			error code
	int iParam2; 	// PIN type											reader state
	int iParam3;	// not used											not used

	char *cParam1;	// command string without data				card answer
	char *cParam2;	// left padding									not used
	char *cParam3;	// right padding									not used

	char *cRFU;		// not used											not used
}	APIEXTENDEDPARAM ;



//==============================================================================

/*#ifdef __cplusplus
extern "C"
{
#endif*/

int _SCR60API PASCAL SLBAPIAllocate(const char *ReaderType, const char *Port, UINT *Handle, LPDWORD pdwState) ;

/*++ 	SLBAPIAllocate:

	 This routine allocates the reader.

Arguments:

	 ReaderType - This supplies the name of the smartcard reader to open.
		  Possible values are: SCR60, SCR60_V310, SCR60_V200, SCT, REFLEX20, REFLEX60

	 Port - This supplies the name of the com port : COM1, COM2, COM3, COM4, PCMCIA.

	 Handle - This receives a value used to refer to this session by other
		  driver calls.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_ABSENT
		  SLBAPI_SWALLOWED
		  SLBAPI_POWERED

		An error leads to one of the following states:

		  SLBAPI_UNKNOWN
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

Remark:

	The number of readers that may be allocated is limited to ten readers.

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPIState(UINT Handle, LPDWORD pdwState, LPDWORD pdwProto, LPBYTE Atr, UINT* AtrLen) ;

/*++ 	SLBAPIState:

	 This routine provides the current state of the reader.  It may be used at
	 any time following a successful call to SLBAPIAllocate, and prior to a
	 successful call to SLBAPIFree. It does not effect the state of the reader or
	 driver.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_ABSENT
		  SLBAPI_SWALLOWED
		  SLBAPI_POWERED
		  SLBAPI_UNKNOWN
		  SLBAPI_NEGOTIABLEMODE
		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

	 pdwProto - This receives the current protocol, if any.  Possible returned
		  values are listed below.  Other values may be added in the future.  The
		  returned value is only meaningful if the returned state is
		  SLBAPI_SPECIFICMODE.

		  SLBAPI_PROTOCOLT0
		  SLBAPI_PROTOCOLT1

	 pbAtr - This parameter points to a 32-byte buffer which receives the ATR
		  string from the currently inserted card, if available.  The TS character
		  is not delivered.

	 pbcAtrLen - This points to a DWORD to receive the number of bytes in the ATR
		  string.  (32 bytes max.)

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPISetCode(UINT Handle, WORD wCode, LPDWORD pdwState);

/*++	SLBAPISetCode (for SCR60 / SCT only)

	This functions changes the select handler command for the SCT / SCR readers.
	The default value for the code is 0510, corresponding to asynchronous cards.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 wCode - This value corresponds to the value of the select handler command (card insertion)
				The MSB may be one of the following values:
					01		FE192 / FE104 card
					03		FE256 card
					04		FE416 card
					05		asynchronous card
					07		EExK card
					08    FE1024 card
					09		cartridge

				The LSB specifies the number of bytes to read from the manufacturer zone of a
				synchronous card. For an asynchronous card, the value is 10.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_ABSENT
		  SLBAPI_SWALLOWED
		  SLBAPI_POWERED
		  SLBAPI_UNKNOWN
		  SLBAPI_NEGOTIABLEMODE
		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPIMonitor(UINT Handle, DWORD dwOldState, LPDWORD pdwNewState) ;

/*++	SLBAPIMonitor:

	 This routine is used by the calling program to monitor the state of a given
	 reader.  The caller supplies the state they believe the reader to be in.
	 The call returns immediately if the state of the reader does not match the
	 expected state, or else it blocks until such time as the reader changes from
	 the given state, or the action is canceled by a call to SLBAPICancel.

	 The only transition detected is card inserted or card removed.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 dwOldState - This supplies the state the caller believes the Reader Driver
		  to be in.

	 pdwNewState - This receives the new changed state of the reader.  Upon
		  success, it returns one of the following state indicators in pdwState:

		  SLBAPI_ABSENT (ok, is card removal is monitored)
		  SLBAPI_SWALLOWED (ok, if card insertion is monitored)

		An error leads to one of the following states:

		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

Remarks :

	If the old state is SLBAPI_ABSENT, the fct returns when the card is inserted.
	Else the fct return when the card is removed.

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPICancel(UINT Handle, LPDWORD pdwState) ;

/*++ 	SLBAPICancel:

	 This routine causes SLBAPIMonitor, SendInsoInT0, SendIsoOutT0 or SendT1
	 operations for the specified handle to be terminated, and to return with
	 a System Error Code indicating that the action was canceled by the user.
	 This call does not effect the state of the reader or Driver.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.

		  SLBAPI_ABSENT
		  SLBAPI_SWALLOWED
		  SLBAPI_POWERED
		  SLBAPI_NEGOTIABLEMODE
		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_UNKNOWN
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPIPowerUp(UINT Handle,LPDWORD pdwState);

/*++	SLBAPIPowerUp:

	 This routine causes the reader to apply power to the card and to reset the
	 card. The reader state must be SLBAPI_SWALLOWED for this operation to be
	 executed. Successful completion of this command changes the Reader Driver
	 state to one of the states listed in the successful return section, below.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_POWERED
		  SLBAPI_NEGOTIABLEMODE
		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_ABSENT
		  SLBAPI_UNKNOWN
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPIPowerDown(UINT Handle, LPDWORD pdwState);

/*++	SLBAPIPowerDown:
		This command cuts the Vcc and the clock. The card is no longer powered.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_SWALLOWED

		An error leads to one of the following states:

		  SLBAPI_ABSENT
		  SLBAPI_UNKNOWN
		  SLBAPI_POWERED
		  SLBAPI_NEGOTIABLEMODE
		  SLBAPI_SPECIFICMODE
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPIReset(UINT Handle, LPDWORD pdwState, LPBYTE pbATR, UINT* pbcAtrLen) ;

/*++	SLBAPIReset:

	 This routine forces a reset of the smartcard. Successful completion of
	 this command changes the Reader Driver state to one of the states listed
	 in the successful return section, below.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_NEGOTIABLEMODE
		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_ABSENT
		  SLBAPI_UNKNOWN
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

	 PbAtr - This points to a 32 byte buffer to receive the ATR string from the
		  card.  The TS character is not delivered.

	 PbcAtrLen - This points to a DWORD to receive the number of bytes in the ATR
		  string.  (32 bytes max.)

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPISendPTS(UINT Handle,LPDWORD pdwState, LPBYTE pbPTS, UINT* pbcPtsLen) ;

/*++ 	SLBAPISendPTS:

		This function sends a PTS request to the card and returns the card answer. For the
		moment, the command is not yet coded. It just returns "FF00FFFF00".

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_ABSENT
		  SLBAPI_UNKNOWN
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

	 pbPTS - This buffer contains PTS command to be send to the card (with checksum).
			When the command has been sent, this buffer receives the card answer.

	 pbcPtsLen - This value contains length of the PTS command to be send and,
			at the return from the function, the length of the answer received from the card.

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPISendIsoInT0(UINT Handle, const LPBYTE Data, UINT Size, LPDWORD pdwState, LPBYTE SW1, LPBYTE SW2) ;

/*++	SLBAPISendIsoInT0:

	This routine send an incomming command in T=0 protocol to the card. The Reader Driver
	state must be either SLBAPI_NEGOTIABLEMODE or SLBAPI_SPECIFICMODE for the command to
	be executed.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_ABSENT
		  SLBAPI_UNKNOWN
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

	Data - This receives the ISO command for the card.

	Size - number of bytes send to the card, i.e. size of the
			command string Data (ASCII representation) divided by 2

	SW1, SW2 - These receive the status code of the card.

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPISendIsoOutT0(UINT Handle, const LPBYTE Data, UINT DataSize, LPDWORD pdwState,
								LPBYTE Answer, UINT *AnswerSize, LPBYTE SW1, LPBYTE SW2) ;

/*++	SLBAPISendIsoOutT0:

	This routine send an outgoing command in T=0 protocol to the card. The Reader Driver
	state must be either SLBAPI_NEGOTIABLEMODE or SLBAPI_SPECIFICMODE for the command to
	be executed.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_ABSENT
		  SLBAPI_UNKNOWN
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

	Data - This receives the ISO command for the card.

	Size - number of bytes send to the card, i.e. size of the
			command string Data (ASCII representation) divided by 2

	Answer - This buffer receives the card answer

	AnswerSize - This value contains the size of the buffer that receives the answer.
			At the return from the function, the value contains the actual answer size.

	SW1, SW2 - These receive the status code of the card.


Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------


int _SCR60API PASCAL SLBAPISendT1(UINT Handle, const LPBYTE Data, UINT DataSize, LPDWORD pdwState,
								LPBYTE Answer, UINT *AnswerSize, LPBYTE SW1, LPBYTE SW2) ;

/*++ 	SLBAPISendT1:
	This routine send acommand in T=1 protocol to the card. The Reader Driver
	state must be either SLBAPI_NEGOTIABLEMODE or SLBAPI_SPECIFICMODE for the command to
	be executed.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Upon success, it
		  returns one of the following state indicators in pdwState:

		  SLBAPI_SPECIFICMODE

		An error leads to one of the following states:

		  SLBAPI_ABSENT
		  SLBAPI_UNKNOWN
		  SLBAPI_UNAVAILABLE
		  SLBAPI_SYSTEMERROR

	Data - This receives the ISO command for the card.

	Size - number of bytes send to the card, i.e. size of the
			command string Data (ASCII representation) divided by 2

	Answer - This buffer receives the card answer

	AnswerSize - This value contains the size of the buffer that receives the answer.
			At the return from the function, the value contains the actual answer size.

	SW1, SW2 - These receive the status code of the card.


Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

int _SCR60API PASCAL SLBAPIFree(UINT Handle,LPDWORD pdwState) ;

/*++	SLBAPIFree:

	 This routine deallocates the specified reader in use by this application,
	 making it available for use by any application.  Successful completion of
	 this command changes the Reader Driver state to one of the states listed in
	 the successful return section, below.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 pdwState - This receives the current state of the reader.  Its value is:

		  SLBAPI_UNAVAILABLE

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	SLBAPI_OK
		Error		--> 	SLBAPI_TIMEOUT, SLBAPI_ABORT, SLBAPI_ERROR

--*/

//------------------------------------------------------------------------------

BOOL _SCR60API PASCAL SLBAPIGetAllocatedReader(UINT Handle, char FAR *ReaderName, UINT SizeName, char FAR *Port, UINT SizePort, LPDWORD pdwState);

/*++	SLBAPIGetAllocatedReader:

	 Reads the name and the allocated port for a given reader handle.
	 Returns also the reader state, that remains unchanged by this function.

Arguments:

	 Handle - This is the reference value returned from the SLBAPIAllocate service.

	 ReaderName - This buffer receives the name of the reader. This may be one of the
			following: SCR60, SCR60_V310, SCR60_V200, SCT, REFLEX20, REFLEX60

	 SizeName - size of the buffer that receives the reader name

	 Port - This buffer receives the name of the allocated port. This may be COM1,
			COM2, COM3, COM4, PCMCIA

	 PortSize - size of the buffer that receives the port name

	 pdwState - This receives the current state of the reader. This value may be any of
			the values mentionned above.

Return Value:

	 An integer value indicating whether or not the service completed
	 successfully.
		Succes	--> 	TRUE
		Error		--> 	FALSE

--*/

//------------------------------------------------------------------------------

BOOL _SCR60API PASCAL SLBAPIAllocateComManager();

/*++	SLBAPIAllocateComManager:

	 Allocates an object that allows to know details about the free ports and
	 the reader types, supported by the DLL. This function must be called
	 before calling any of the following functions.

Arguments:

	 none

Return Value:

		Succes	--> 	TRUE
		Error		--> 	FALSE

--*/

//------------------------------------------------------------------------------

BOOL _SCR60API PASCAL SLBAPIFreeComManager();

/*++	SLBAPIFreeComManager:

	 Frees the COM-Manager. Do not forget to call this function !

Arguments:

	 none

Return Value:

		Succes	--> 	TRUE
		Error		--> 	FALSE

--*/

//------------------------------------------------------------------------------

UINT _SCR60API PASCAL SLBAPIGetNbrReaders();

/*++	SLBAPIGetNbrReaders:

	 Returns the number of readers known to the DLL.

Arguments:

	 none

Return Value:

		Succes	--> 	number of readers
		Error		--> 	-1

--*/

//------------------------------------------------------------------------------

BOOL _SCR60API PASCAL SLBAPIGetReaderName(UINT i, char FAR *ReaderName, UINT SizeName, BYTE *ReaderType);

/*++	SLBAPIGetReaderName:

	 Returns the name of the i-th reader and its type.

Arguments:

	 ReaderName - This buffer receives the name of the reader. This may be one of the
			following: SCR60, SCR60_V310, SCR60_V200, SCT, REFLEX20, REFLEX60

	 SizeName - size of the buffer that receives the reader name

	 ReaderType - a byte that indicates the reader type. May be either SLBAPI_RT_SERIAL
			or SLBAPI_RT_PCMCIA (Reflex 20 only).

Return Value:

		Succes	--> 	TRUE
		Error		--> 	FALSE

--*/

//------------------------------------------------------------------------------

UINT _SCR60API PASCAL SLBAPIGetNbrFreePorts();

/*++	SLBAPIGetNbrReaders:

	 Returns the number of free ports.

Arguments:

	 none

Return Value:

		Succes	--> 	number of free ports
		Error		--> 	-1

--*/

//------------------------------------------------------------------------------

BOOL _SCR60API PASCAL SLBAPIGetFreePort(UINT, char FAR *, UINT, BYTE*);

/*++	SLBAPIGetReaderName:

	 Returns the name of the i-th free port and its type.

Arguments:

	 ReaderName - This buffer receives the name of the port. This may be one of the
			following: COM1, COM2, COM3, COM4, PCMCIA

	 SizeName - size of the buffer that receives the name of the free port

	 ReaderType - a byte that indicates the reader type. May be either SLBAPI_RT_SERIAL
			or SLBAPI_RT_PCMCIA.

Return Value:

		Succes	--> 	TRUE
		Error		--> 	FALSE

Remark: The PCMCIA is only detected, if a Reflex 20 is present.

--*/

//------------------------------------------------------------------------------


void _SCR60API PASCAL Info_Version(char*);

//-------------------------------------
// Modifications Y.D.
// Europe Informatique
//
// Nouvelles fonctions d'interface
//-------------------------------------

BOOL _SCR60API PASCAL SLBAPIGetLastError(UINT, char*, UINT);

DWORD _SCR60API PASCAL SLBAPISetHandler(UINT, LPDWORD, char*);

BOOL _SCR60API PASCAL SLBAPIGetFirmwareVersion(UINT, char*, UINT*);

/*
#ifdef __cplusplus
}
#endif
*/


#endif
